structs

package
v0.0.0-...-98c81bf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2024 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Structs

type Structs struct{}

func (Structs) Equals

func (s Structs) Equals(s1 interface{}, s2 interface{}) bool

Return true if the two structs given are equal. Else, false.

func (Structs) IsStruct

func (s Structs) IsStruct(v any) bool

Return true if the value given is a struct. Else, false.

Jump to