Documentation
¶
Index ¶
- func Equals(v1 any, v2 any) bool
- func ExpectKind(v any, expected string)
- func ExpectType(v any, expected string)
- func HasKind(v any, expected string) bool
- func HasType(v any, expected string) bool
- func IsArray(v any) bool
- func IsBasic(v any) bool
- func IsComparable(v any) bool
- func IsMap[V any](v V) bool
- func IsOrdered(v any) bool
- func KindString(v any) string
- func TypeEquals(v1 any, v2 any) bool
- func TypeString(v any) string
- type Kind
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Equals ¶
Return true if the values given are equal. Else, false. TODO: accomodate structs, slices, arrays, maps and other structures
func ExpectKind ¶
Panic if the value given is not of the kind given. TODO: Test after collections is rolled out
func ExpectType ¶
Panic if the value given is not of the type given. TODO: Test after collections is rolled out
func HasKind ¶
Return true if the kind of the value given equals the expected kind given. Else, false.
func HasType ¶
Return true if the type of the value given equals the expected type given. Else, false.
func IsComparable ¶
Return true if the value given is comparable. Else, false.
func TypeEquals ¶
Return true if the values given are of the same type. Else, false.
func TypeString ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.